@@ -1,6 +1,6 @@
 ##############################################################################
 #
-# Copyright (c) 2004 Zope Foundation and Contributors.
+# Copyright (c) 2004 Zope Corporation and Contributors.
 # All Rights Reserved.
 #
 # This software is subject to the provisions of the Zope Public License,
@@ -12,12 +12,14 @@
 #
 ##############################################################################
 """Zope Application Server Generations
+
+$Id: __init__.py 116577 2010-09-18 12:11:54Z icemac $
 """
 __docformat__ = "reStructuredText"
 
-from zope.app.generations.generations import SchemaManager
+from zope.generations.generations import SchemaManager
 # BBB import
-from zope.app.generations.utility import getRootFolder
+from zope.generations.utility import getRootFolder
 
 
 key = 'zope.app.zopeappgenerations'
